==> anabel-0.0.1.tar.gz: anabel-0.0.1/docs/index.md <==
---
is_homepage: true
hide_toc: true
full_width: true
template: particles.html
---
<style>
.home-feature {
  justify-content: space-between !important;
  align-items: center !important; 
  display: flex !important;
  margin-top: 3rem !important;
  margin-bottom: 3rem !important;
}
</style>

<header>
<div class="hero position-relative overflow-hidden p-3 text-center text-dark">
    <div class="col-md-5 p-lg-1 mx-auto my-5">
        <p><img src="img/emtec-4.png" alt="" width=100><h2></img>anabel</h2></p>
        <p class="lead ">anabel Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
    </p>
    <a class="btn btn-outline-primary btn-lg" href="starting" role="button">Get Started</a>
    </div>
    <div class="product-device box-shadow d-none d-md-block"></div>
    <div class="product-device product-device-2 box-shadow d-none d-md-block"></div>
</div>
</header>

<main role="main">
<div class="container marketing p-md-5">
<hr class="featurette-divider">
    <div class="row featurette p-4">
    <div class="row text-center">
        <div class="col-lg-4">
        <p><a class="btn btn-outline-secondary" href="Guides/" role="button">Guides</a></p>
        <p class="lead">View guides that explain the concepts and components of <code>anabel</code>.</p>
        </div><!-- /.col-lg-4 -->

        <div class="col-lg-4">
        <p><a class="btn btn-outline-secondary" href="api/latest" role="button">API Documentation</a></p>
        <p class="lead">Peruse a comprehensive list of functions provided by<code>anabel</code>, with detailed explanations of their interfaces.</p>
        </div><!-- /.col-lg-4 -->

        <div class="col-lg-4">
            <p><a class="btn btn-outline-secondary" href="gallery/" role="button">Gallery</a></p>
        <p class="lead">Walk through some examples of the various analysis procedures that <code>anabel</code> provides.</p>
        </div><!-- /.col-lg-4 -->
    </div><!-- /.row -->
    </div><!-- /.row-featurette -->

<hr class="featurette-divider">

<article><div class="row featurette home-feature feature">
    <div class="col-7">
      <h2 class="featurette-heading">Inelasticity</h2>
      <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
      <!--<a class="btn btn-outline-secondary" href="Guides/Developing" role="button">Developer's Manual</a>-->
    </div>
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/pde-iso.svg" class="img-fluid"/>
    </div>
</div></article>

<article><div class="row featurette home-feature feature">
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/pde-iso.svg" class="img-fluid"/>
    </div>
    <div class="col-7">
      <h2 class="featurette-heading">Partial Differential Equations</h2>
      <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
      <!--<a class="btn btn-outline-secondary" href="Guides/Developing" role="button">Developer's Manual</a>-->
    </div>
</div></article>

<div  class="home-feature row featurette">
  <div class="col-md-7">
    <h2 class="featurette-heading">Reliability</h2>
    <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
    <!-- <a class="btn btn-outline-secondary" href="Functions/latest/Utility_Functions/Plotting//Functions/latest/Utility_Functions/Plotting/" role="button">Library </a> -->
    </div>
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/reliability.svg" class="img-fluid"/>
    </div>
  </div>
</div>

<!-- <hr class="featurette-divider">
<section id="supporters">
<div class="container supporters">
    <h2>Acknowledgements</h2>
    <p class="lead">Development of <code>anabel</code> has been made possible through the following past and present supportorters:<p>
    <div class="row">
    <div class="col supporter">
        <a href="https://ce.berkeley.edu/programs/semm"><img src="img/UCBEngineering_logo.png" alt="SEMM logo"></a>
    </div>
    <div class="col supporter">
        <a href="https://www.support.link.2"><img src="_static/support_logo_2.png" alt="Support logo 2"></a>
    </div>
    </div>
    <div class="row">
    <div class="col supporter">
        <a href="https://www.support_link3.missing"><img src="_static/support_logo_3.png" alt="Support logo 3"></a>
    </div>
    <div class="col supporter">
        <a href=""><img src="_static/nvidia_logo.png" alt="Support logo 4"></a>
    </div>
    </div>
</div>
</section> -->

<!-- <hr class="featurette-divider"> -->

<!-- </section> -->

</main>

<!-- <section id="ucb-fea"> -->
<!-- <div class="container supporters">
    <h3>Other UC Berkeley FEA tools</h3>
    <div class="row">
    <div class="col">
        <a href="https://www.support.link.2"><img src="_static/support_logo_2.png" alt="FEAP"></a>
    </div>
    <div class="col">
        <a href="https://www.support_link3.missing"><img src="_static/support_logo_3.png" alt="OpenSees"></a>
    </div>
    <div class="col">
        <a href=""><img src="_static/logo.png" alt="SimCenter"></a>
    </div>
    </div>
</div> -->
<!-- Code highlighting -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.6.0/prism.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.6.0/components/prism-python.min.js"></script>

<!-- Claudio Perez  -->

==> anabel-0.0.5.tar.gz: anabel-0.0.5/docs/index.md <==
---
is_homepage: true
hide_toc: true
full_width: true
template: particles.html
---
<style>
.home-feature {
  justify-content: space-between !important;
  align-items: center !important; 
  display: flex !important;
  margin-top: 3rem !important;
  margin-bottom: 3rem !important;
}
</style>

<header>
<div class="hero position-relative overflow-hidden p-3 text-center text-dark">
    <div class="col-md-5 p-lg-1 mx-auto my-5">
        <p><img src="img/anabel.svg" alt="" width=200><h2 style="font-size:60px;font-weight:50 !important;"></img>anabel</h2></p>
        <p class="lead ">anabel Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
    </p>
    <a class="btn btn-outline-primary btn-lg" href="guides/quick-start" role="button">Get Started</a>
    </div>
    <div class="product-device box-shadow d-none d-md-block"></div>
    <div class="product-device product-device-2 box-shadow d-none d-md-block"></div>
</div>
</header>

<main role="main">
<div class="container marketing p-md-5">
<hr class="featurette-divider">
    <div class="row featurette p-4">
    <div class="row text-center">
        <div class="col-lg-4">
        <p><a class="btn btn-outline-secondary" href="guides/" role="button">Guides</a></p>
        <p class="lead">View guides that explain the concepts and components of <code>anabel</code>.</p>
        </div><!-- /.col-lg-4 -->

        <div class="col-lg-4">
        <p><a class="btn btn-outline-secondary" href="api/latest" role="button">API Documentation</a></p>
        <p class="lead">Peruse a comprehensive list of functions provided by<code>anabel</code>, with detailed explanations of their interfaces.</p>
        </div><!-- /.col-lg-4 -->

        <div class="col-lg-4">
            <p><a class="btn btn-outline-secondary" href="gallery/" role="button">Gallery</a></p>
        <p class="lead">Walk through some examples of the various analysis procedures that <code>anabel</code> provides.</p>
        </div><!-- /.col-lg-4 -->
    </div><!-- /.row -->
    </div><!-- /.row-featurette -->

<hr class="featurette-divider">

<article><div class="row featurette home-feature feature">
    <div class="col-7">
      <h2 class="featurette-heading">Inelasticity</h2>
      <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
      <!--<a class="btn btn-outline-secondary" href="Guides/Developing" role="button">Developer's Manual</a>-->
    </div>
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/pde-iso.svg" class="img-fluid"/>
    </div>
</div></article>

<article><div class="row featurette home-feature feature">
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/pde-iso.svg" class="img-fluid"/>
    </div>
    <div class="col-7">
      <h2 class="featurette-heading">Partial Differential Equations</h2>
      <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
      <!--<a class="btn btn-outline-secondary" href="Guides/Developing" role="button">Developer's Manual</a>-->
    </div>
</div></article>

<div  class="home-feature row featurette">
  <div class="col-md-7">
    <h2 class="featurette-heading">Reliability</h2>
    <p class="lead">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
    <!-- <a class="btn btn-outline-secondary" href="Functions/latest/Utility_Functions/Plotting//Functions/latest/Utility_Functions/Plotting/" role="button">Library </a> -->
    </div>
    <div class="col-4" style="position: relative;">
      <img style="vertical-align:middle; max-width: 100%; height: auto" src="img/reliability.svg" class="img-fluid"/>
    </div>
  </div>
</div>

<!-- <hr class="featurette-divider">
<section id="supporters">
<div class="container supporters">
    <h2>Acknowledgements</h2>
    <p class="lead">Development of <code>anabel</code> has been made possible through the following past and present supportorters:<p>
    <div class="row">
    <div class="col supporter">
        <a href="https://ce.berkeley.edu/programs/semm"><img src="img/UCBEngineering_logo.png" alt="SEMM logo"></a>
    </div>
    <div class="col supporter">
        <a href="https://www.support.link.2"><img src="_static/support_logo_2.png" alt="Support logo 2"></a>
    </div>
    </div>
    <div class="row">
    <div class="col supporter">
        <a href="https://www.support_link3.missing"><img src="_static/support_logo_3.png" alt="Support logo 3"></a>
    </div>
    <div class="col supporter">
        <a href=""><img src="_static/nvidia_logo.png" alt="Support logo 4"></a>
    </div>
    </div>
</div>
</section> -->

<!-- <hr class="featurette-divider"> -->

<!-- </section> -->

</main>

<!-- <section id="ucb-fea"> -->
<!-- <div class="container supporters">
    <h3>Other UC Berkeley FEA tools</h3>
    <div class="row">
    <div class="col">
        <a href="https://www.support.link.2"><img src="_static/support_logo_2.png" alt="FEAP"></a>
    </div>
    <div class="col">
        <a href="https://www.support_link3.missing"><img src="_static/support_logo_3.png" alt="OpenSees"></a>
    </div>
    <div class="col">
        <a href=""><img src="_static/logo.png" alt="SimCenter"></a>
    </div>
    </div>
</div> -->
<!-- Code highlighting -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.6.0/prism.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.6.0/components/prism-python.min.js"></script>

<!-- Claudio Perez  -->
